.. FabIO documentation master file, created by
   sphinx-quickstart on Fri Mar 15 09:03:50 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to FabIO's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   getting_started
   install
   performances
   Changelog
   man/fabio_viewer
   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

